@@ -7,9 +7,9 @@ package Require::HookChain::munge::prepend;
 #END IFUNBUILT
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-02-12'; # DATE
+our $DATE = '2023-04-22'; # DATE
 our $DIST = 'Require-HookChain'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 sub new {
     my ($class, $preamble) = @_;
@@ -43,16 +43,20 @@ Require::HookChain::munge::prepend - Prepend a piece of code to module source
 
 =head1 VERSION
 
-This document describes version 0.011 of Require::HookChain::munge::prepend (from Perl distribution Require-HookChain), released on 2023-02-12.
+This document describes version 0.012 of Require::HookChain::munge::prepend (from Perl distribution Require-HookChain), released on 2023-04-22.
 
 =head1 SYNOPSIS
 
- use Require::HookChain 'munge::prepend' => 'use strict';
+ use Require::HookChain 'munge::prepend' => 'use strict'; # the semicolon and newline is added automatically
 
 The above has a similar effect to:
 
  use everywhere 'strict';
 
+because it will prepend this line to each source code being loaded:
+
+ use strict;
+
 =head1 DESCRIPTION
 
 =for Pod::Coverage .+
